@@ -115,7 +115,9 @@ class Hostname implements RouteInterface
         $level      = 0;
 
         while ($currentPos < $length) {
-            preg_match('(\G(?P<literal>[a-z0-9-.]*)(?P<token>[:{\[\]]|$))', $def, $matches, 0, $currentPos);
+            if (!preg_match('(\G(?P<literal>[a-z0-9-.]*)(?P<token>[:{\[\]]|$))', $def, $matches, 0, $currentPos)) {
+                throw new Exception\RuntimeException('Matched hostname literal contains a disallowed character');
+            }
 
             $currentPos += strlen($matches[0]);
 
@@ -266,7 +268,7 @@ class Hostname implements RouteInterface
     public function match(Request $request)
     {
         if (!method_exists($request, 'getUri')) {
-            return null;
+            return;
         }
 
         $uri  = $request->getUri();
@@ -275,7 +277,7 @@ class Hostname implements RouteInterface
         $result = preg_match('(^' . $this->regex . '$)', $host, $matches);
 
         if (!$result) {
-            return null;
+            return;
         }
 
         $params = array();
